@@ -60,6 +60,9 @@ class Node(_common.ListMixin, resource.Resource):
     #: The UUID of the allocation associated with this node. Added in API
     #: microversion 1.52.
     allocation_id = resource.Body("allocation_uuid")
+    #: A string or UUID of the tenant who owns the baremetal node. Added in API
+    #: microversion 1.50.
+    owner = resource.Body("owner")
     #: The UUID of the chassis associated wit this node. Can be empty or None.
     chassis_id = resource.Body("chassis_uuid")
     #: The current clean step.
@@ -337,11 +340,11 @@ class Node(_common.ListMixin, resource.Resource):
         if config_drive:
             # Some config drive actions require a higher version.
             if isinstance(config_drive, dict):
-                version = _common.CONFIG_DRIVE_DICT_VERSION
+                version = '1.56'
             elif target == 'rebuild':
-                version = _common.CONFIG_DRIVE_REBUILD_VERSION
+                version = '1.35'
 
-        version = self._assert_microversion_for(session, 'commit', version)
+        version = utils.pick_microversion(session, version)
 
         body = {'target': target}
         if config_drive:
@@ -523,7 +526,7 @@ class Node(_common.ListMixin, resource.Resource):
         else:
             version = None
 
-        version = self._assert_microversion_for(session, 'commit', version)
+        version = utils.pick_microversion(session, version)
 
         # TODO(dtantsur): server timeout support
         body = {'target': target}
@@ -830,5 +833,39 @@ class Node(_common.ListMixin, resource.Resource):
 
         self.traits = traits
 
+    def patch(self, session, patch=None, prepend_key=True, has_body=True,
+              retry_on_conflict=None, base_path=None, reset_interfaces=None):
+
+        if reset_interfaces is not None:
+            # The id cannot be dirty for an commit
+            self._body._dirty.discard("id")
+
+            # Only try to update if we actually have anything to commit.
+            if not patch and not self.requires_commit:
+                return self
+
+            if not self.allow_patch:
+                raise exceptions.MethodNotSupported(self, "patch")
+
+            session = self._get_session(session)
+            microversion = utils.pick_microversion(session, '1.45')
+            params = [('reset_interfaces', reset_interfaces)]
+
+            request = self._prepare_request(requires_id=True,
+                                            prepend_key=prepend_key,
+                                            base_path=base_path, patch=True,
+                                            params=params)
+
+            if patch:
+                request.body += self._convert_patch(patch)
+
+            return self._commit(session, request, 'PATCH', microversion,
+                                has_body=has_body,
+                                retry_on_conflict=retry_on_conflict)
+
+        else:
+            return super(Node, self).patch(session, patch=patch,
+                                           retry_on_conflict=retry_on_conflict)
+
 
 NodeDetail = Node
